{pkgs', ...}: let
  bashFktScript = import ./bash-fkt.nix {
    inherit pkgs';
  };
in
  pkgs'.writeShellScriptBin "update-inputs" ''

    source ${pkgs'.common}/bin/common
    ${bashFktScript}

    echo_header "Update inputs"
    echo_hint "The command is executed in the current working directory and not in a nix derivation."
    cd_working_dir

    echo_section "Updating inputs for the following packages:"
    selection=$(${pkgs'.gum}/bin/gum choose --no-limit "Version")
    exitCode=$?
    if [[ $exitCode -ne 0 ]]; then
      echo_ok "Exiting."
      exit 0
    fi

    packages=($selection)
    echo "Updating inputs for the following packages: ''${packages[@]}"

    if [[ "''${packages[@]}" == "" || $exitCode -ne 0 ]]; then
      echo_ok "Exiting."
      exit 0
    fi

    for package in "''${packages[@]}"; do
        echo_step "$package updating"

        ## pck is the package name (to lower with flake suffix
        pck=$(echo "$package" | tr '[:upper:]' '[:lower:]' | sed 's/ /-/g')

        if ! ${pkgs'.nix}/bin/nix flake lock --update-input "$pck"Flake; then
            echo_fail "$package failed to update"
        else
            echo_ok "$package updated"
        fi
    done

  ''
